#
# spec file for package caja
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname libcaja-extension1
%define typelib typelib-1_0-Caja-2_0
%define _version 1.28

Name:           caja
Version:        1.28.0
Release:        1.1
Summary:        File manager for the MATE desktop
License:        GPL-2.0-only AND LGPL-2.0-only
URL:            https://mate-desktop.org/
Group:          Productivity/File utilities
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(exempi-2.0)
BuildRequires:  pkgconfig(gail-3.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk-layer-shell-0)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mate-desktop-2.0) >= %{_version}
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(wayland-client)
Recommends:     %{name}-lang
# mate-file-manager was last used in openSUSE 13.1.
Provides:       mate-file-manager = %{version}
Obsoletes:      mate-file-manager < %{version}
Obsoletes:      mate-file-manager-lang < %{version}

%description
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

%lang_package

%package devel
Summary:        Caja development files
Requires:       %{lname} = %{version}
Requires:       %{name} = %{version}
Group:          Development/Libraries/X11
# mate-file-manager-devel was last used in openSUSE 13.1.
Provides:       mate-file-manager-devel = %{version}
Obsoletes:      mate-file-manager-devel < %{version}

%description devel
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

%package -n %{lname}
Summary:        Caja shared libraries
Group:          System/Libraries
Requires:       %{name}-gschemas >= %{version}

%description -n %{lname}
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.


# Needed for using pluma as standalone from MATE.

%package gschemas
Summary:        Caja GSchemas
Group:          System/GUI/Other
Obsoletes:      mate-file-manager < %{version}
# caja-gsettings-schemas was last used in openSUSE Leap 42.1.
Obsoletes:      %{name}-gsettings-schemas < %{version}
Provides:       %{name}-gsettings-schemas = %{version}
%glib2_gsettings_schema_requires

%description gschemas
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

This package provides the GSettings schemas for Caja.

%package -n %{typelib}
Summary:        MATE file manager typelib
Group:          System/Libraries

%description -n %{typelib}
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

%prep
%autosetup -p1

%build
NOCONFIGURE=1 mate-autogen
%configure --disable-update-mimedb \
           --disable-static\
           --enable-wayland \
           --enable-introspection
%make_build

%install
%make_install
%find_lang %{name}
find %{buildroot} -type f -name "*.la" -delete -print
# Create extensions directories.
mkdir -p %{buildroot}%{_libdir}/caja/extensions-2.0/ \
  %{buildroot}%{_datadir}/caja/extensions/ \
  %{buildroot}%{_datadir}/caja-extensions/

%suse_update_desktop_file caja-autorun-software
%suse_update_desktop_file caja-browser
%suse_update_desktop_file caja-computer
%suse_update_desktop_file caja-file-management-properties
%suse_update_desktop_file caja-folder-handler
%suse_update_desktop_file caja-home
%suse_update_desktop_file caja
%suse_update_desktop_file mate-network-scheme

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files
%license COPYING COPYING.EXTENSIONS COPYING.LIB
%doc AUTHORS NEWS
%{_bindir}/caja
%{_bindir}/caja-autorun-software
%{_bindir}/caja-connect-server
%{_bindir}/caja-file-management-properties
%{_datadir}/caja/
%{_datadir}/dbus-1/services/org.mate.freedesktop.FileManager1.service
%{_datadir}/applications/caja-autorun-software.desktop
%{_datadir}/applications/caja-browser.desktop
%{_datadir}/applications/caja-computer.desktop
%{_datadir}/applications/caja-file-management-properties.desktop
%{_datadir}/applications/caja-folder-handler.desktop
%{_datadir}/applications/caja-home.desktop
%{_datadir}/applications/caja.desktop
%{_datadir}/applications/mate-network-scheme.desktop
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/pixmaps/*
%{_datadir}/mime/packages/*
%{_mandir}/man?/*.?%{?ext_man}
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/caja.appdata.xml
# Own common extensions directories.
%dir %{_libdir}/caja/
%dir %{_libdir}/caja/extensions-2.0/
%dir %{_datadir}/caja/extensions/
%dir %{_datadir}/caja-extensions/

%files lang -f caja.lang

%files -n %{typelib}
%{_libdir}/girepository-1.0/Caja-2.0.typelib

%files -n %{lname}
%{_libdir}/*.so.*

%files gschemas
%{_datadir}/glib-2.0/schemas/*.xml

%files devel
%{_datadir}/gtk-doc/html/libcaja-extension/
%{_includedir}/caja/
%{_libdir}/*.so
%{_libdir}/pkgconfig/libcaja-extension.pc
%{_datadir}/gir-1.0/Caja-2.0.gir

%changelog
* Sun Mar 24 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Translation update
  * Wl bgleaks fixes (#1763)
  * wayland-background-dialog: fix two issues found by cppcheck
  * wayland-background-dialog: ensure style provider is added only once
  * eel-background: fix logic error in x11/wayland detection
  * wayland-background-dialog: Preview images at original aspect ratio
  * wayland-background-dialog: fix memory leaks
  * wayland background dialog: fix build warning
  * Make wayland background dialog more intuitive
  * Manage desktop backgrounds when running in wayland
  * wayland desktop: suppress spatial window warning
  * Do not show "Organize Desktop by Name" when desktop icons are locked
  * fix building with libxml 2.12.0
- Drop caja-glib-2.54.patch
* Thu Nov 16 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.3
  * update translations
  * caja-file: fix future informal date bug
  * caja-file: fix yesterday/today informal date bug
  * Replace deprecated code from xrandr
  * caja-desktop-window: Fix the xrandr error
* Mon Jul 18 2022 Mihai Moldovan <ionic@ionic.de>
- Update to upstream version 1.26.1:
  * tx: sync with transifex
  * Fix Caja does not show icons of application launchers
  * caja-mime-actions: fix memory leak
  * caja-bookmark: fix memory leak
  * caja-bookmark: drop create_image_cairo_for_bookmark
  * caja-file-conflict-dialog: Move to automatic signal
    disconnection
  * caja-file-conflict-dialog: Properly release references on
    dispose()
  * caja-file-conflict-dialog: update the icons once
  * caja-module: fix memory leak
  * caja-sidebar-title: fix memory leak
  * fm-directory-view: fix memory leak
  * eel-background: fix memory leak
  * caja-application: avoid SEGV when profiling/debugging code
  * caja-places-sidebar: fix right-click menu height
- No packaging changes necessary.
* Wed Aug 11 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Update translations
  * Update copyright to 2021
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.24.1
  * update translations
  * file-operations: don't attempt to move into the source dir
  * keep one .desktop suffix on desktop file renaming
  * fix runtime warning from newly unused code
  * Confirm before deleting during an undo operation
  * Updating the link of caja
* Wed Jul 15 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Replace pkgconfig(gail) with pkgconfig(gail-3.0) BuildRequires:
  align with what configure checks for, and no longer pull in
  unneeded nor used gtk2-devel.
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0 (changes since 1.23.1):
  * caja-progress-info: Use NotifyNotification instead of
    GNotification.
  * Copy file and keep timestamps of original file including
    remotes.
  * Fix Caja crashes on file move in Korean.
  * Support querying files by contained text.
  * Use show icons option in views tab.
  * Add preference option to hide icons in list view.
  * fm-directory-view: Add icon to "empty trash" into "File" menu.
  * gla11y: Use version 0.3 which already defaults to using
    python3.
  * caja-places-sidebar: Add icon to "empty trash".
  * spatial-window: Replace geprecated gtk_menu_popup.
  * property-browser: Replace deprecated gtk_drag_begin.
  * fm-list-view: Replace deprecated gtk_drag_begin.
  * Show thumbnails in list view.
  * file-manager: Reduce the scope of some variables.
  * preferences: Render extension icons as cairo_surfaces.
  * preferences: Render media icons as cairo_surface.
  * Replace gdkpixbuf with cairo_surfaces in a few more places.
  * sidebar: Render info icon as vector.
  * desktop: Add specific CSS for ContrastHigh and
    ContrastHighInverse.
  * desktop: Add specific CSS for HighContrast and
    HighContrastInverse.
  * Add support for loading theme-specific caja-desktop CSS.
  * Refactor custom CSS loading into a separate function.
  * Add support for checking .ui accessibility with gla11y.
  * Render file-conflict icons as cairo_surface vectors.
  * file-conflict-dialog: Don't scale icons twice on hidpi monitors.
  * eel-string: Fix "make check".
  * Restore transparent background on icon view labels.
  * desktop icon view: Disconnect callback from correct GSettings
    instance.
  * Add scroll tabs with mouse wheel for File's properties and
    caja's preferences windows.
  * hidpi: Ensure all icons are properly scaled.
  * Use GETTEXTDATADIRS replace GETTEXTDATADIR.
  * Create msgstr for data/browser.xml.
  * Add gettext ITS.
  * Migrate intltool to gettext.
  * fm-properties: Remove use of mate-desktop-thumbnail helper.
  * Make device ejection notifications translatable.
  * Keep path same when opening new window from an existing one.
  * editable-label: Don't hyphenate filenames.
  * libcaja-private/caja-file: Redundant condition.
  * Avoid redundant redeclarations.
  * canvas-item: Don't hyphenate filenames.
  * change name from caja.{its,loc} to mimeinfo.{its,loc}.
  * caja-window-slot: "folder-saved-search" icon instead
    "text-x-generic".
  * Let some strings be translatable.
  * Add document for CajaWidgetViewProvider api.
  * Add new interface.
  * Add CajaWidgetViewProvider docs.
  * Add new extension for widget view.
  * Hide menu and toolbutton when view is only one.
  * Set FmWidgetView is single view.
  * Add new FmWidgetView object.
  * Fix build error about autoptr clean.
  * Use absolute path of binary on desktop files.
  * build: Fix wrong executing dir in caja.desktop.
  * Set a real title on the desktop window (as provided to ATK).
  * Drop GLIB version check.
  * build: Show compiler flags on configuration summary.
  * Fix build using the -fno-common flag.
  * Update translations.
- Drop support for old openSUSE versions.
- Add caja-glib-2.54.patch: restore GLib 2.54 support.
* Wed Jul 17 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.1 (changes since 1.22.1):
  * desktop: Always draw the items label frame
  * suppress GtkAction deprecations warnings
  * src: reduce the scope of some variables
  * caja-open-with-dialog: cppcheck: Redundant condition
  * eel-canvas: cppcheck: Local variable 'allocation' shadows outer variable
  * caja-progress-info: add tooltips to file transfer dialog
  * Add accessible names for buttons in file transfer operations dialog
  * libegg: reduce the scope of some variables
  * libcaja-private: reduce the scope of some variables
  * eel: remove date & time functions
  * caja-spatial-window: Unused variable i
  * eel: reduce the scope of some variables
  * caja-location-dialog: Fix 'cppcheck' and 'clang' warnings
  * update translations
  * caja-property-browser: Fix cast from non-struct type to struct type
  * eggsmclient-xsmp: Fix cast from non-struct type to struct type
  * caja-file-utilities: Fix cast from non-struct type to struct type
  * local #include files who are libraries inside <> instead ""
  * eel-string: Use 'va_copy' instead of 'G_VA_COPY'
  * eel-editable-label: Use 'memmove' instead of 'memcpy'
  * eel: remove eel_g_object_list_ref
  * drop functions defined but not used
  * local #include files inside "" instead <>
  * caja-icon-canvas-item: avoid 'cppcheck' warning
  * caja-file: avoid shifting signed 32-bit value by 31 bits
  * caja-icon-canvas-item: initialize variable 'scale'
  * caja-application: avoid NULL inside 'g_object_unref'
  * fm-desktop-icon-view: remove dead code
  * caja-file-operations: make sure 'error' isn't NULL
  * caja-open-with-dialog: make sure there is error before showing it
  * eel-string: Fix: 'memcpy' overflows destination buffer
  * eel-string: avoid 'memcpy' with NULL argument
  * caja-progress-info: make sure argument is initialized
  * eel: replace eel_ref_str with GRefString
  * eel: remove g_object_list_copy
  * caja-sidebar-title: avoid 'NULL' inside 'setup_gc_with_fg'
  * caja-file: Fix incomplete file replacement dialog
  * caja-autorun: avoid NULL in 'memcpy'
  * eel-editable-label: call argument with initialized value
  * caja-file: Fix: true and false branches are identical
  * caja-file-operations: add comment with false positive warning:
  * configure.ac: fix portability issue with test
  * eel: remove g_str_list_copy
  * Remove USE_MATE2_MACROS from autogen.sh (legacy)
  * eel: remove g_list_free_deep_custom
  * avoid variables set but not used
  * eel-canvas: Fix warning: Undefined or garbage value returned to caller
  * caja-window: Fix garbage value
  * eel-gdk-pixbuf-extensions: Fix division by zero
  * Fix use of memory after it is freed.
  * Fix attempt to free released memory
  * drop unused variables
- remove patches:
  * caja-missing-include.patch: builds fine without it
  * caja-gtk-3.20.patch: we don't support gtk3.20 anymore
- build require gtk >= 3.22, glib >= 2.50 and gio >= 2.50
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * caja-progress-info: Make sure argument is initialised.
  * Fix invocation with --geometry from the command line.
  * Pass "NULL" for keyboard event.
  * caja-file: Fix incomplete file replacement dialogue.
  * eel-gdk-pixbuf-extensions: Fix division by zero.
  * caja-file: Fix use of memory after it is freed.
  * caja-icon-container: Fix use of memory after it is freed.
  * fm-tree-model: Fix use of memory after it is freed.
  * caja-information-panel: Fix use of memory after it is freed.
  * fm-directory-view: Fix use of memory after it is freed.
  * caja-tree-view-drag-dest: Fix memory leak.
  * [Security] eel-string: Use "g_strlcat" instead of "strcat".
  * [Security] Use "g_strlcpy" instead of "strcpy".
  * Update translations.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Avoid deprecated GtkStock.
  * Avoid deprecated GtkImageMenuItem.
  * libcaja-private/caja-recent.c: gvfs-open is a deprecated tool,
    switch to "gio open" from libglib2.0-bin.
  * caja-query-editor.c: Add "#include <eel/eel-stock-dialogs.h>".
  * caja-file-management-properties.ui: Avoid deprecated GtkVBox
    and GtkHBox.
  * caja-bookmarks-window.ui: Avoid deprecated functions.
  * Rename mate_dialog_add_button to eel_dialog_add_button.
  * caja-spatial-window.c: Avoid deprecated GtkVBox.
  * Eliminate accessible children-changed event flood on container
    repopulation.
  * Eliminate accessible children-changed event flood during update
    all.
  * Emit accessible-name-change signal for icons only when icons
    are renamed.
  * sidebar popup menu: Show "media-eject" icon in the "unmount"
    items.
  * pathbar: Fix random segfaults on opening mounts from Desktop.
  * fm-icon-view: Show size on disc as sort criterion.
  * sidebar popup menu: Show "media-eject" icon.
  * Add sort criterion by reversed extension segments.
  * fm-tree-view.c: Drop unused variable.
  * Rename "mate_image_menu_item..." to
    "eel_image_menu_item_new_from_icon".
  * eel-gtk-extensions: Show icons in right-click menus only if
    "menus-have-icons" is set.
  * caja-sidebar-title: Fix: images broken in sidebar.
  * caja-progress-info.c: Show notifications in begin/end of
    progress.
  * caja-progress-info.c: Avoid deprecated
    "gtk_status_icon_get_visible".
  * caja-sidebar-title: Fix a -Wmaybe-uninitialized warning.
  * caja-desktop-window.c: Fix: caja crashes unexpectedly.
  * Avoid deprecated "gtk_widget_override_font".
  * Avoid deprecated "gtk_window_set_wmclass".
  * caja-bookmark.c: Drop unused variable.
  * caja-bookmark.c: Fix icons in bookmarks.
  * icon-container: Avoid deprecated
    "gtk_style_context_get_border_color".
  * Avoid deprecated "gtk_dialog_get_action_area".
  * Pathbar button: Fix poor response to right-click.
  * editable-label: Avoid deprecated
    "gtk_im_multicontext_append_menuitems".
  * Use NULL instead of an uninitialised variable.
  * eel-editable-label.c: Avoid deprecated gdk_keymap_get_default.
  * eel-editable-label: Avoid deprecated
    gtk_style_context_set_background.
  * zoom-control: Don't use the eel_pop_up_context_menu function.
  * Replace deprecated gtk_menu_popup.
  * libcaja-private: Replace deprecated gdk_error_trap functions.
  * fm-desktop-icon-view: Replace deprecated
    gdk_error_trap_push/pop functions.
  * Replace deprecated gdk_flush.
  * libcaja-private: Fix -Wlogical-not-parentheses build warning.
  * Avoid deprecated gtk_style_context_get_background_color.
  * GSettings should init before use it.
  * monitor: Fix a crash on unmounting remote filesystems.
  * CajaFile: Fix a crash in modify_link_hash_table.
  * connect-server-dialog: Respect password save setting.
  * properties-window: Fix checking inconsistent state.
  * monitor: Watch for removal of non-native mounts on
    GVolumeMonitor.
  * Add "Configurable" interface and add support to
    caja-file-management-properties.
  * caja-application.c: Remove redundant empty lines.
  * Update caja manpage with info about "--force-desktop" option.
  * Caja-icon-info: Optimise icon lookups by GIcon.
  * fm-directory-view.c:  Decrease minimum update interval.
  * Remove dead code, fix a memory leak.
  * Add option to open multiple uri in tabs at startup.
  * Add the ability to switch tabs using [ctrl+tab] and
    [ctrl+shift+tab].
  * caja-desktop-directory: Stop segfaults in
    directory_ready_callback.
  * caja-directory.c: Fix a build warning.
  * pathbar: Increase reference count of path in
    update_button_types.
  * Fix some issues found by static analysis.
  * pathbar: Fix crash when accessing drive root.
  * libcaja-private: Remove redundant prefs application to hash
    table.
  * [desktop-bg] Fix a memory leak during background change events.
  * caja-location-bar: Fix: change background colour based on
    activity state.
  * Avoid deprecated g_type_class_add_private under src.
  * Fix incompatible pointer types.
  * Avoid deprecated g_type_class_add_private under src.
  * Avoid deprecated g_type_class_add_private under
    libcaja-private.
  * Fix compile warning.
  * Let file size units follow the users preference.
  * Fixed the value of 6 month and 1 year.
  * Support querying files by modification time and size.
  * Avoid deprecated g_type_class_add_private.
  * CajaApplication: Avoid deprecated g_type_class_add_private.
  * caja-menu: Avoid deprecated g_type_class_add_private.
  * eel, libegg: Use G_DEFINE_TYPE_WITH_PRIVATE macro.
  * configure.ac: Add check for PKG_CONFIG being set.
  * caja-application: Check for smclient before trying to load
    session.
  * eel: Avoid deprecated g_type_class_add_private.
  * libegg: Avoid deprecated g_type_class_add_private.
  * libcaja-private: Re-check file MIME type before picking an
    application.
  * file-manager: Fix apparent bug in context menu updating code.
  * Revert "fm-directory-view.c:  Decrease minimum update interval.".
  * Fix: weird item in bookmarks if the directory was removed.
  * Minor code-quality enhancements.
  * Forgot to initialise is_backup field.
  * Change show/hide backup files shortcut.
  * Remove useless comments, correct description string.
  * Skip hidden files only, not backups.
  * Add independent show/hide backup files.
  * Deleting an unused nautilus icon.
  * caja-progress-info: New behaviour with notifications.
  * caja-progress-info: Show notifications with the gsettings key.
  * Move AppStream files to the metainfo/ directory.
  * caja-places-sidebar: Replace two other uses of
    g_drive_poll_for_media_finish.
  * caja-bookmark: Fix memory leak.
  * eel-gtk-extensions: Fix memory leaks.
  * Add update-authors.pl script which helps to update caja.about.
  * Read authors and documenters fom caja.about file.
  * Ensure proper translation of the about dialogue title
  * Add --disable-self-check for configure.
  * Update translations.
- Rebase caja-gtk-3.20.patch.
- Add caja-missing-include.patch: Add a missing include.
* Thu Dec 13 2018 sor.alexei@meowr.ru
- Update to version 1.20.3:
  * Disable deprecation warnings for distcheck.
  * Fix segfault on stopping USB hard drives.
  * fm-properties-window: Fix memory leaks.
  * caja-desktop-link-monitor: Fix a memory leak.
  * Fix case-sensitive comparison in running_in_mate.
  * pathbar: Activate pane when changing location.
  * caja-window: Fix: mouse doesn't work with
    [ctrl] + [.] or [ctrl] + [;].
  * desktop window: Add is-desktop AtkObject attribute.
  * Update translations.
- Rebase caja-gtk-3.20.patch.
* Wed Apr 11 2018 sor.alexei@meowr.ru
- Update to version 1.20.2 (changes since 1.20.0):
  * Remove a runtime warning in usage of
    caja_clipboard_set_up_editable.
  * Can select all the search keywords with Ctrl+a.
  * Fix backgrounds and emblems dialogue content rendering.
  * Fix warnings from HiDPI commits.
  * sidebar: Respect sidebar dimensions on HiDPI.
  * HiDPI: Convert Pixbufs to Cairo Surfaces.
  * general: Use gdk_monitor_get_scale_factor.
  * list-view: Use the cairo surface as a drag icon.
  * Scale screen dimensions.
  * icon-info: Hash/store icons using scale factor as well as size.
  * file: Support HiDPI for thumbnails images.
  * properties-window: Support HiDPI for the properties window
    icon.
  * Support HiDPI icons.
  * canvas-container: Listen to scale factor to invalidate icons.
  * canvas-item: Use gtk_render_icon_surface for the DnD surface.
  * desktop-canvas-view: Scale desktop workarea.
  * modify code error: End the statement with a semicolon.
  * Update translations.
- Rebase caja-gtk-3.20.patch.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Use gtk+-3 bookmarks location.
  * Expand grid width to canvas.
  * Use atk_component_get_extents instead of
    atk_component_get_position.
  * don't parse .hidden files manually - GIO does it since 2.36.
  * Don't check the nonexistent MATE22_USER_DIR env var.
  * Don't check the nonexistent ~/.mate2 directory.
  * eel-accessibility: Remove unused code and outdated comments.
  * eel: Queue resizes on the canvas as elements change visibility.
  * Add size_request to IconContainer to work around unncecessary
    relayouting.
  * eel: Remove unneeded #include with condition.
  * eel: Remove some unused code from eel-gdk-pixbuf-extensions.
  * gtk 3.22: Avoid deprecated gdk_screen_get_monitor_ functions.
  * Refresh all rows on zoom change.
  * Force widget redraw on zoom.
  * libcaja-private: Remove wrong link from internal README.
  * private: Ensure we allow launching .desktop files from trusted
    symlinks.
  * Fix scaling the desktop wallpaper not working.
  * Avoid deprecated gdk_screen_width/height(),
    gdk_screen_get_width/height(), gdk_screen_make_display_name().
  * libegg: Replace deprecated gtk_drag_begin()
  * eggsmclient: Fix a build warning because of -Wcomment.
  * Don't use deprecated gtk_show_uri.
  * Avoid deprecated gdk_screen_get_number().
  * Add a feature: Present the size on the drive of files as we
    present the size of the file.
  * Reword the Size on Disk column description a bit.
  * Make sure scaling the desktop wallpaper works in all monitors.
  * An implementation of WidthOfScreen and HeightOfScreen.
  * caja-places-sidebar: Fix refusal to unmount when sidebar is
    wide.
  * caja-places-sidebar: Disable the overlay scrollbar.
  * Require GTK+ 3.22 and GLib 2.50.
  * Fix tasklist icon change when opening new tab.
  * Include local files with "" instead of <>.
  * search_dispose and search_finilize can't be run after search
    had finished.
  * Add a missing window icon to the About dialogue for extensions.
  * Move libegg to the top srcdir and drop some leftovers.
  * Remove the +x attr from source files.
  * Restore Polish translation credits from GNOME.
  * Update translations.
- Add caja-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20 support.
- Remove caja-gtk3-bookmarks.patch: fixed upstream.
- Make the library package require caja-gschemas less strictly
  version-wise.
* Tue Nov 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.5:
  * Fix wrong behaviour with the "enter" key when renaming files in
    list view.
  * Open a directory in new window: [ctrl] + [shift] + [w].
  * zoom-control: Change zoom with mousewheel scroll over button.
  * View -> Visible Columns: Fix vertical expand of dialogue
    content.
  * Fix wrong <Shift+Del> behaviour when renaming files.
  * Fix high cpu when loading background image.
  * icon-dnd: Remove a hardcoded highlight frame.
  * list view: Fix large icon margins on zooming out.
  * Remove a weird +x attribute from a source file.
* Thu Aug 31 2017 sor.alexei@meowr.ru
- Update to version 1.18.4:
  * Fix zoom in list-view.
  * pathbar: Enable mousewheel scrolling like it was with GTK+2.
  * open-with-dialog: Set max-char-width for a label.
  * Fix "Open With" dialog ue"Open" button's text misalignment.
  * caja-pathbar: Fix off-by-one error.
  * Fix browsing/autorun media on insertion.
  * Fix vertical Compact View scrolling in
    fm_icon_view_scroll_event().
* Thu May 11 2017 sor.alexei@meowr.ru
- Update to version 1.18.3:
  * Restore D-Bus interface initialisation.
  * CSS: Load a different caja-desktop.css with GTK+ 3.14.
  * file: Make caja_file_get_gicon return custom icons too
    (gh#mate-desktop/caja#765).
  * Open With dialogue: Force the icon size.
  * Show correct right-click menu after making a selection.
- Add caja-gtk3-bookmarks.patch: Use the Gtk3 bookmarks location
  (commit 65f573c).
* Sat Apr 15 2017 sor.alexei@meowr.ru
- Update to version 1.18.2:
  * Icon and compact view: Fix scrolling and renaming in large
    directories.
  * IconCanvasItem: Fix overlapping filenames on hover.
* Tue Apr  4 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Fix a build warning.
  * search: Add tag support (xattr::xdg.tags).
  * Fix broken rename in list view by selectin file name cell.
  * property-browser: Add style class frame to scrolledwindows.
  * caja-application.c: Fix an uninitialised variable.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Build: Require libmate-desktop >= 1.17.3.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Port from libunique to GtkApplication.
  * Implement copy queue and pausing.
  * Add an option for asking confirmation before moving files to
    trash.
  * Add support for back/forward mouse buttons for directory
    navigation.
  * Add a notification when ejected drives are safe to unplug
    (and require libnotify at build time).
  * Add a --force-desktop command line option to make Caja always
    manage the desktop.
  * Add an ability to get feedback from Orca when additional icons
    are selected/deselected.
  * Drop the metadata converting tool.
  * Fix crossfade issues with recent GTK+ versions.
  * Fix more graphics issues to allow Caja to use background for
    directory windows.
  * Fix some more GTK+ deprecations and runtime warnings.
  * Schema: some fixes and cleanups.
  * Update translations.
* Sun Feb  5 2017 sor.alexei@meowr.ru
- Update to version 1.16.2:
  * List view: Show/hide columns instead of appending/removing them
    (fixes crash when moving between trash and other directory with
    GTK+3).
  * Icon view: Fix accessibility issues.
  * Icon and compact views: Fix moving to next/previous row (or
    column) with right/left (or down/up) keys.
  * Preferences dialogue: Fix vertical expand of content with
    window resize.
  * Show "Open with" menu item and "Open with" tab in properties
    window for .desktop and .theme files.
  * Fix cursor refresh issues on directory change in single click
    mode.
  * Fix runtime warnings on window closing and Caja exit.
  * GTK+3: Fix mousewheel scrolling in compact view.
  * GTK+3: Fix visual issues when renaming files.
  * GTK+3: Force the X11 backend.
  * Some more fixes and cleanups.
* Tue Oct 18 2016 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Fix a regression that sometimes caused visual glitches when
    selecting icons.
  * GTK+3: Some CSS adjustments.
  * GTK+3: Fix accessibility on desktop (for Orca).
  * GTK+3: Fix several runtime warnings.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Use GtkAboutDialog instead of MateAboutDialog.
  * Pathbar: Always show right arrow button.
  * Fix changing taskbar icon when switching between tabs with
    different icons.
  * Fix lots of warnings when building docs for libcaja-extension.
  * GTK+3: Add style classes for elements of pathbar.
  * GTK+3: Fix drawing and changing of desktop background with
    Gtk 3.21.
  * GTK+3: Fix a large amount of deprecations.
  * Some more fixes and cleanups.
  * Update translations.
* Wed Aug 10 2016 sor.alexei@meowr.ru
- Update to version 1.14.2:
  * Make distcheck use currently selected GTK+ version.
  * Update translations.
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * prefs dialog: Don't crash on toggling "Show hidden and backup
    files".
  * GTK+-3 theming: Add a CSS file for caja, and initialise it at
    startup.
  * GTK+3: Add style class caja-desktop-window at top level.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Drop MateConf migration script.
  * Allow closing tabs on middle-click.
  * List Python extensions separately in extensions list.
  * GTK+3: Add several style classes to simplify theming.
  * GTK+3: Fix desktop flash issue.
  * GTK+3: A lot of deprecation fixes.
  * Some more fixes and cleanups.
  * Update translations.
  * Add Changelog generation.
* Tue Mar 29 2016 sor.alexei@meowr.ru
- Update to 1.12.7:
  * Fix remaining random changes of font color in icon view.
* Tue Mar 15 2016 sor.alexei@meowr.ru
- Update to 1.12.6:
  * Really fix loading multiple python extensions.
* Mon Mar 14 2016 sor.alexei@meowr.ru
- Update to 1.12.5:
  * Fix loading multiple Python extensions.
  * GTK+3: fix crash on Ctrl + scroll wheel.
- Rename caja-gsettings-schemas package to caja-gschemas.
* Thu Feb 18 2016 sor.alexei@meowr.ru
- Update to 1.12.4:
  * Fix random crash on startup when python-caja extension is
    enabled.
  * Fix crash when restoring file with special characters from
    trash.
  * Fix few memleaks.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to 1.12.3:
  * Fix wrong text colour in icon view with some light themes.
  * Fix crash due to unneeded assert.
* Wed Dec 23 2015 sor.alexei@meowr.ru
- Update 1.12.2:
  * Set smclient mode to "no restart" when either running as root
    or on other desktops.
  * Properties -> custom icon dialog: add missing /usr/share/icons/
    to Places.
  * Some other fixes.
* Sat Dec 12 2015 p.drouand@gmail.com
- Remove useless pkgconfig(pangox) requirement
* Sun Nov 29 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Assorted bugfixes.
  * Update translations.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * GTK+3 fixes.
* Fri Oct  9 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Connect to server dialog: add support for AFP.
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Switch to org.gnome.SessionManager for logout/suspend inhibit.
  * Improve multi-monitor support.
  * Some UI fixes.
* Thu Sep 24 2015 sor.alexei@meowr.ru
- Update to 1.10.4:
  * Fix a crash when using undo following a file deletion.
* Tue Jul 21 2015 sor.alexei@meowr.ru
- Update to 1.10.3:
  * File properties dialog: bring back missing Notes and
    Image Properties tabs.
* Fri Jul 17 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Places sidebar: enable both creating bookmarks and dropping
    files.
  * Compact view: don't auto-scroll to the right on long filenames.
  * Don't manage desktop and exit with last window when either
    running as root or on other desktops.
  * Fix double-click behaviour when clicking on a folder and then
    on a file / directory inside it.
  * GTK+3 fixes.
  * Update translations update.
* Fri Jun 12 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Do not automount USB flash drives and CD/DVD drives while
    session is locked.
  * Revert dropping of files to Bookmarks sidebar.
  * UI bugfixes.
- Spec cleanup.
* Tue Apr 14 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * Bug fixes release
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Bug fixes release
* Mon Mar 23 2015 p.drouand@gmail.com
- Own the new caja extensions directory
* Tue Jan 13 2015 p.drouand@gmail.com
- Update to version 1.9.4 (unstable)
  + Allow extensions to be enabled/disabled at runtime
  + Bugfixes
* Tue Nov 11 2014 p.drouand@gmail.com
- Update to version 1.9.3 (unstable)
  + Allow extensions to be enabled/disabled at runtime
  + Bugfixes
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  + bugfixes release
* Fri Oct  3 2014 p.drouand@gmail.com
- Update to version 1.8.2
  + limit deep scount (folder contents and size) to one filesystem
  + Handle metadata key deletions
  + Propagate button-release event when ejecting
  + Fix text renderinf on no background
* Sat Apr 26 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + accessibility improvements
  + fixed x-caja-desktop issue
  + removed ConsoleKit usage
  + show trash icon in tree side panel
* Mon Mar 10 2014 p.drouand@gmail.com
- Add several obsoletes to avoid a lot of conflicts with
  mate-file-manager
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Wed Feb 19 2014 p.drouand@gmail.com
- Update to version 1.7.90
  + add GTK3 support
  + re add bookmark section in connect server dialog
  + add option to show file sizes with IEC units instead of SI units
  + add "Open parent location" in menu if we are in search view
* Mon Feb 10 2014 p.drouand@gmail.com
- Initial release (version 1.7.2)
